Changelog
=========

Version 0.2.0
-------------
* Bug fix in Bullet Widget.
* Allow Bullet Widget to return more than one Bullet Widget.

Version 0.1.0
-------------
* First release, split off from django-geckoboard_.

.. _django-analytical: http://pypi.python.org/pypi/django-geckoboard
